@@ -41,7 +41,7 @@ see https://www.gnu.org/licenses/.  */
 #if ! defined (__GMP_WITHIN_CONFIGURE)
 #define __GMP_HAVE_HOST_CPU_FAMILY_power   0
 #define __GMP_HAVE_HOST_CPU_FAMILY_powerpc 0
-#define GMP_LIMB_BITS                      32
+#define GMP_LIMB_BITS                      64
 #define GMP_NAIL_BITS                      0
 #endif
 #define GMP_NUMB_BITS     (GMP_LIMB_BITS - GMP_NAIL_BITS)
@@ -2331,8 +2331,8 @@ enum
 };
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
-#define __GMP_CC "armv6j-unknown-linux-musleabihf-gcc"
-#define __GMP_CFLAGS "-O2 -pipe -march=armv6j -mfpu=vfp -mfloat-abi=hard"
+#define __GMP_CC "x86_64-pc-linux-gnu-gcc"
+#define __GMP_CFLAGS " -O3 -pipe -Wall -Wformat -Wformat-security -fgraphite-identity -floop-nest-optimize -ftree-loop-distribution -flto=8 -fuse-linker-plugin -fdevirtualize-at-ltrans -fipa-pta -fno-semantic-interposition -D_GLIBCXX_ASSERTIONS -ftrivial-auto-var-init=pattern -fstack-protector-strong -fstack-clash-protection -fexceptions -fPIE -fPIC -D_FORTIFY_SOURCE=3"
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
